gridgeo
-------

[![PyPI](https://img.shields.io/pypi/v/gridgeo.svg?style=plastic)](https://pypi.python.org/pypi/gridgeo) [![Build Status](https://travis-ci.org/pyoceans/gridgeo.svg?branch=master)](https://travis-ci.org/pyoceans/gridgeo) [![DOI](https://zenodo.org/badge/5715/pyoceans/gridgeo.svg)](https://zenodo.org/badge/latestdoi/5715/pyoceans/gridgeo)

Converts ocean numerical models grids,
including UGRID and SGRID compliant files,
to a variety of geo-like objects: GeoJSON, and shapefile.

For some examples check the [notebook folder](https://nbviewer.jupyter.org/github/pyoceans/gridgeo/tree/master/notebooks/).
